@@ -27,10 +27,13 @@
 
 #include <QtGui/QWidget>
 
+#include <KGlobal>
+#include <KLocale>
 
 using namespace Akonadi;
 
 // @cond PRIVATE
+#define AKONADI_CONTROL_SERVICE QLatin1String( "org.freedesktop.Akonadi.Control" )
 
 AgentInstance AgentManagerPrivate::createInstance( const AgentType &type )
 {
@@ -176,6 +179,17 @@ void AgentManagerPrivate::agentInstanceNameChanged( const QString &identifier, c
   emit mParent->instanceNameChanged( instance );
 }
 
+void AgentManagerPrivate::serviceOwnerChanged( const QString &service, const QString &oldOwner, const QString &newOwner )
+{
+  Q_UNUSED( oldOwner );
+  Q_UNUSED( newOwner );
+
+  if ( service != AKONADI_CONTROL_SERVICE )
+    return;
+
+  createDBusInterface();
+}
+
 void AgentManagerPrivate::readAgentTypes()
 {
   QDBusReply<QStringList> types = mManager->agentTypes();
@@ -191,8 +205,8 @@ AgentType AgentManagerPrivate::fillAgentType( const QString &identifier ) const
 {
   AgentType type;
   type.d->mIdentifier = identifier;
-  type.d->mName = mManager->agentName( identifier );
-  type.d->mDescription = mManager->agentComment( identifier );
+  type.d->mName = mManager->agentName( identifier, KGlobal::locale()->language() );
+  type.d->mDescription = mManager->agentComment( identifier, KGlobal::locale()->language() );
   type.d->mIconName = mManager->agentIcon( identifier );
   type.d->mMimeTypes = mManager->agentMimeTypes( identifier );
   type.d->mCapabilities = mManager->agentCapabilities( identifier );
@@ -261,52 +275,69 @@ AgentInstance AgentManagerPrivate::fillAgentInstanceLight( const QString &identi
   return instance;
 }
 
+void AgentManagerPrivate::createDBusInterface()
+{
+  mTypes.clear();
+  mInstances.clear();
+
+  delete mManager;
+  mManager = new org::freedesktop::Akonadi::AgentManager( AKONADI_CONTROL_SERVICE,
+                                                          QLatin1String( "/AgentManager" ),
+                                                          QDBusConnection::sessionBus(), mParent );
+
+  QObject::connect( mManager, SIGNAL( agentTypeAdded( const QString& ) ),
+                    mParent, SLOT( agentTypeAdded( const QString& ) ) );
+  QObject::connect( mManager, SIGNAL( agentTypeRemoved( const QString& ) ),
+                    mParent, SLOT( agentTypeRemoved( const QString& ) ) );
+  QObject::connect( mManager, SIGNAL( agentInstanceAdded( const QString& ) ),
+                    mParent, SLOT( agentInstanceAdded( const QString& ) ) );
+  QObject::connect( mManager, SIGNAL( agentInstanceRemoved( const QString& ) ),
+                    mParent, SLOT( agentInstanceRemoved( const QString& ) ) );
+  QObject::connect( mManager, SIGNAL( agentInstanceStatusChanged( const QString&, int, const QString& ) ),
+                    mParent, SLOT( agentInstanceStatusChanged( const QString&, int, const QString& ) ) );
+  QObject::connect( mManager, SIGNAL( agentInstanceProgressChanged( const QString&, uint, const QString& ) ),
+                    mParent, SLOT( agentInstanceProgressChanged( const QString&, uint, const QString& ) ) );
+  QObject::connect( mManager, SIGNAL( agentInstanceNameChanged( const QString&, const QString& ) ),
+                    mParent, SLOT( agentInstanceNameChanged( const QString&, const QString& ) ) );
+  QObject::connect( mManager, SIGNAL( agentInstanceWarning( const QString&, const QString& ) ),
+                    mParent, SLOT( agentInstanceWarning( const QString&, const QString& ) ) );
+  QObject::connect( mManager, SIGNAL( agentInstanceError( const QString&, const QString& ) ),
+                    mParent, SLOT( agentInstanceError( const QString&, const QString& ) ) );
+  QObject::connect( mManager, SIGNAL( agentInstanceOnlineChanged( const QString&, bool ) ),
+                    mParent, SLOT( agentInstanceOnlineChanged( const QString&, bool ) ) );
+
+  if ( mManager->isValid() ) {
+    QDBusReply<QStringList> result = mManager->agentTypes();
+    if ( result.isValid() ) {
+      foreach( const QString &type, result.value() ) {
+        const AgentType agentType = fillAgentType( type );
+        mTypes.insert( type, agentType );
+      }
+    }
+
+    result = mManager->agentInstances();
+    if ( result.isValid() ) {
+      foreach( const QString &instance, result.value() ) {
+        const AgentInstance agentInstance = fillAgentInstance( instance );
+        mInstances.insert( instance, agentInstance );
+      }
+    }
+  }
+}
+
 AgentManager* AgentManagerPrivate::mSelf = 0;
 
 AgentManager::AgentManager()
   : QObject( 0 ), d( new AgentManagerPrivate( this ) )
 {
-  d->mManager = new org::freedesktop::Akonadi::AgentManager( QLatin1String( "org.freedesktop.Akonadi.Control" ),
-                                                     QLatin1String( "/AgentManager" ),
-                                                     QDBusConnection::sessionBus(), this );
+  d->createDBusInterface();
 
-  connect( d->mManager, SIGNAL( agentTypeAdded( const QString& ) ),
-           this, SLOT( agentTypeAdded( const QString& ) ) );
-  connect( d->mManager, SIGNAL( agentTypeRemoved( const QString& ) ),
-           this, SLOT( agentTypeRemoved( const QString& ) ) );
-  connect( d->mManager, SIGNAL( agentInstanceAdded( const QString& ) ),
-           this, SLOT( agentInstanceAdded( const QString& ) ) );
-  connect( d->mManager, SIGNAL( agentInstanceRemoved( const QString& ) ),
-           this, SLOT( agentInstanceRemoved( const QString& ) ) );
-  connect( d->mManager, SIGNAL( agentInstanceStatusChanged( const QString&, int, const QString& ) ),
-           this, SLOT( agentInstanceStatusChanged( const QString&, int, const QString& ) ) );
-  connect( d->mManager, SIGNAL( agentInstanceProgressChanged( const QString&, uint, const QString& ) ),
-           this, SLOT( agentInstanceProgressChanged( const QString&, uint, const QString& ) ) );
-  connect( d->mManager, SIGNAL( agentInstanceNameChanged( const QString&, const QString& ) ),
-           this, SLOT( agentInstanceNameChanged( const QString&, const QString& ) ) );
-  connect( d->mManager, SIGNAL( agentInstanceWarning( const QString&, const QString& ) ),
-           this, SLOT( agentInstanceWarning( const QString&, const QString& ) ) );
-  connect( d->mManager, SIGNAL( agentInstanceError( const QString&, const QString& ) ),
-           this, SLOT( agentInstanceError( const QString&, const QString& ) ) );
-  connect( d->mManager, SIGNAL(agentInstanceOnlineChanged(QString,bool)),
-           SLOT(agentInstanceOnlineChanged(QString,bool)) );
-
-  if ( d->mManager->isValid() ) {
-    QDBusReply<QStringList> result = d->mManager->agentTypes();
-    if ( result.isValid() ) {
-      foreach( const QString &type, result.value() ) {
-        const AgentType agentType = d->fillAgentType( type );
-        d->mTypes.insert( type, agentType );
-      }
-    }
-
-    result = d->mManager->agentInstances();
-    if ( result.isValid() ) {
-      foreach( const QString &instance, result.value() ) {
-        const AgentInstance agentInstance = d->fillAgentInstance( instance );
-        d->mInstances.insert( instance, agentInstance );
-      }
-    }
+  // if the D-Bus interface is not valid at this point, watch for the
+  // service to appear and create a new one then
+  if ( !d->mManager->isValid() ) {
+    connect( QDBusConnection::sessionBus().interface(),
+             SIGNAL(serviceOwnerChanged(QString,QString,QString)),
+             SLOT(serviceOwnerChanged(QString,QString,QString)) );
   }
 }
 
