@@ -44,7 +44,7 @@ class Collection;
  *   Akonadi::AgentManager *manager = Akonadi::AgentManager::self();
  *
  *   Akonadi::AgentType::List types = manager->types();
- *   foreach( const Akonadi::AgentType type&, types ) {
+ *   foreach( const Akonadi::AgentType& type, types ) {
  *     qDebug() << "Type:" << type.name() << type.description();
  *   }
  *
@@ -80,7 +80,7 @@ class AKONADI_EXPORT AgentManager : public QObject
      * Returns the agent type with the given @p identifier or
      * an invalid agent type if the identifier does not exist.
      */
-    AgentType type( const QString &identififer ) const;
+    AgentType type( const QString &identifier ) const;
 
     /**
      * Returns the list of all available agent instances.
@@ -198,6 +198,7 @@ class AKONADI_EXPORT AgentManager : public QObject
     Q_PRIVATE_SLOT( d, void agentInstanceWarning( const QString&, const QString& ) )
     Q_PRIVATE_SLOT( d, void agentInstanceError( const QString&, const QString& ) )
     Q_PRIVATE_SLOT( d, void agentInstanceOnlineChanged( const QString&, bool ) )
+    Q_PRIVATE_SLOT( d, void serviceOwnerChanged( QString, QString, QString ) )
     //@endcond
 };
 
