@@ -503,11 +503,10 @@ void ICalFormatImpl::writeIncidence( icalcomponent *parent,
   }
 
   // categories
-  QStringList categories = incidence->categories();
-  QStringList::const_iterator it;
-  for ( it = categories.constBegin(); it != categories.constEnd(); ++it ) {
+  QString categories = incidence->categories().join( "," );
+  if ( !categories.isEmpty() ) {
     icalcomponent_add_property(
-      parent, icalproperty_new_categories( (*it).toUtf8() ) );
+      parent, icalproperty_new_categories( categories.toUtf8() ) );
   }
 
   // related event
@@ -768,6 +767,14 @@ icalproperty *ICalFormatImpl::writeAttendee( Attendee *attendee )
     icalproperty_add_parameter( p, icalparameter_delegator );
   }
 
+  const QMap<QByteArray, QString> customMap = attendee->customProperties().customProperties();
+  for ( QMap<QByteArray, QString>::ConstIterator cit = customMap.constBegin();
+        cit != customMap.constEnd(); ++cit ) {
+    icalparameter *icalparameter_x = icalparameter_new_x( cit.value().toUtf8() );
+    icalparameter_set_xname( icalparameter_x, cit.key() );
+    icalproperty_add_parameter( p, icalparameter_x );
+  }
+
   return p;
 }
 
@@ -856,49 +863,50 @@ icalrecurrencetype ICalFormatImpl::writeRecurrenceRule( RecurrenceRule *recur )
   bys = recur->bySeconds();
   index = 0;
   for ( it = bys.constBegin(); it != bys.constEnd(); ++it ) {
-    r.by_second[index++] = *it;
+    r.by_second[index++] = static_cast<short>( *it );
   }
 
   bys = recur->byMinutes();
   index = 0;
   for ( it = bys.constBegin(); it != bys.constEnd(); ++it ) {
-    r.by_minute[index++] = *it;
+    r.by_minute[index++] = static_cast<short>( *it );
   }
 
   bys = recur->byHours();
   index = 0;
   for ( it = bys.constBegin(); it != bys.constEnd(); ++it ) {
-    r.by_hour[index++] = *it;
+    r.by_hour[index++] = static_cast<short>( *it );
   }
 
   bys = recur->byMonthDays();
   index = 0;
   for ( it = bys.constBegin(); it != bys.constEnd(); ++it ) {
-    r.by_month_day[index++] = icalrecurrencetype_day_position( (*it) * 8 );
+    short d = static_cast<short>( ( *it ) * 8 );
+    r.by_month_day[index++] = static_cast<short>( icalrecurrencetype_day_position( d ) );
   }
 
   bys = recur->byYearDays();
   index = 0;
   for ( it = bys.constBegin(); it != bys.constEnd(); ++it ) {
-    r.by_year_day[index++] = *it;
+    r.by_year_day[index++] = static_cast<short>( *it );
   }
 
   bys = recur->byWeekNumbers();
   index = 0;
   for ( it = bys.constBegin(); it != bys.constEnd(); ++it ) {
-    r.by_week_no[index++] = *it;
+    r.by_week_no[index++] = static_cast<short>( *it );
   }
 
   bys = recur->byMonths();
   index = 0;
   for ( it = bys.constBegin(); it != bys.constEnd(); ++it ) {
-    r.by_month[index++] = *it;
+    r.by_month[index++] = static_cast<short>( *it );
   }
 
   bys = recur->bySetPos();
   index = 0;
   for ( it = bys.constBegin(); it != bys.constEnd(); ++it ) {
-    r.by_set_pos[index++] = *it;
+    r.by_set_pos[index++] = static_cast<short>( *it );
   }
 
   QList<RecurrenceRule::WDayPos> byd = recur->byDays();
@@ -913,7 +921,7 @@ icalrecurrencetype ICalFormatImpl::writeRecurrenceRule( RecurrenceRule *recur )
     } else {
       day += (*dit).pos() * 8;
     }
-    r.by_day[index++] = day;
+    r.by_day[index++] = static_cast<short>( day );
   }
 
   r.week_start =
@@ -921,7 +929,7 @@ icalrecurrencetype ICalFormatImpl::writeRecurrenceRule( RecurrenceRule *recur )
 
   if ( recur->frequency() > 1 ) {
     // Dont' write out INTERVAL=1, because that's the default anyway
-    r.interval = recur->frequency();
+    r.interval = static_cast<short>( recur->frequency() );
   }
 
   if ( recur->duration() > 0 ) {
@@ -1055,8 +1063,6 @@ Todo *ICalFormatImpl::readTodo( icalcomponent *vtodo, ICalTimeZones *tzlist )
 
   icalproperty *p = icalcomponent_get_first_property( vtodo, ICAL_ANY_PROPERTY );
 
-  QStringList categories;
-
   while ( p ) {
     icalproperty_kind kind = icalproperty_isa(p);
     switch ( kind ) {
@@ -1117,9 +1123,6 @@ Event *ICalFormatImpl::readEvent( icalcomponent *vevent, ICalTimeZones *tzlist )
 
   icalproperty *p = icalcomponent_get_first_property( vevent, ICAL_ANY_PROPERTY );
 
-  QStringList categories;
-  icalproperty_transp transparency;
-
   bool dtEndProcessed = false;
 
   while ( p ) {
@@ -1151,13 +1154,15 @@ Event *ICalFormatImpl::readEvent( icalcomponent *vevent, ICalTimeZones *tzlist )
       break;
 
     case ICAL_TRANSP_PROPERTY:  // Transparency
-      transparency = icalproperty_get_transp( p );
+    {
+      icalproperty_transp transparency = icalproperty_get_transp( p );
       if ( transparency == ICAL_TRANSP_TRANSPARENT ) {
         event->setTransparency( Event::Transparent );
       } else {
         event->setTransparency( Event::Opaque );
       }
       break;
+    }
 
     default:
       // TODO: do something about unknown properties?
@@ -1196,7 +1201,6 @@ FreeBusy *ICalFormatImpl::readFreeBusy( icalcomponent *vfreebusy )
   icalproperty *p = icalcomponent_get_first_property( vfreebusy, ICAL_ANY_PROPERTY );
 
   FreeBusyPeriod::List periods;
-
   while ( p ) {
     icalproperty_kind kind = icalproperty_isa( p );
     switch ( kind ) {
@@ -1332,16 +1336,20 @@ Attendee *ICalFormatImpl::readAttendee( icalproperty *attendee )
   }
 
   p = icalproperty_get_first_parameter( attendee, ICAL_X_PARAMETER );
+  QMap<QByteArray, QString> custom;
   while ( p ) {
     QString xname = QString( icalparameter_get_xname( p ) ).toUpper();
     QString xvalue = QString::fromUtf8( icalparameter_get_xvalue( p ) );
     if ( xname == "X-UID" ) {
       uid = xvalue;
+    } else {
+      custom[xname.toUtf8()] = xvalue;
     }
     p = icalproperty_get_next_parameter( attendee, ICAL_X_PARAMETER );
   }
 
   Attendee *a = new Attendee( name, email, rsvp, status, role, uid );
+  a->customProperties().setCustomProperties( custom );
 
   p = icalproperty_get_first_parameter( attendee, ICAL_DELEGATEDTO_PARAMETER );
   if ( p ) {
@@ -1605,9 +1613,20 @@ void ICalFormatImpl::readIncidence( icalcomponent *parent,
       break;
 
     case ICAL_CATEGORIES_PROPERTY:  // categories
+    {
+      // We have always supported multiple CATEGORIES properties per component
+      // even though the RFC seems to indicate only 1 is permitted.
+      // We can't change that -- in order to retain backwards compatibility.
       text = icalproperty_get_categories( p );
-      categories.append( QString::fromUtf8( text ) );
+      const QString val = QString::fromUtf8( text );
+      foreach ( const QString &cat, val.split( ',', QString::SkipEmptyParts ) ) {
+        // ensure no duplicates
+        if ( !categories.contains( cat ) ) {
+          categories.append( cat );
+        }
+      }
       break;
+    }
 
     case ICAL_RRULE_PROPERTY:
       readRecurrenceRule( p, incidence );
@@ -1830,7 +1849,7 @@ void ICalFormatImpl::readRecurrence( const struct icalrecurrencetype &r,
   }
 
   // Week start setting
-  int wkst = ( r.week_start + 5 ) % 7 + 1;
+  short wkst = static_cast<short>( ( r.week_start + 5 ) % 7 + 1 );
   recur->setWeekStart( wkst );
 
   // And now all BY*
@@ -1866,10 +1885,10 @@ void ICalFormatImpl::readRecurrence( const struct icalrecurrencetype &r,
   // BYDAY is a special case, since it's not an int list
   QList<RecurrenceRule::WDayPos> wdlst;
   short day;
-  index=0;
+  index = 0;
   while ( ( day = r.by_day[index++] ) != ICAL_RECURRENCE_ARRAY_MAX ) {
     RecurrenceRule::WDayPos pos;
-    pos.setDay( ( icalrecurrencetype_day_day_of_week( day ) + 5 ) % 7 + 1 );
+    pos.setDay( static_cast<short>( ( icalrecurrencetype_day_day_of_week( day ) + 5 ) % 7 + 1 ) );
     pos.setPos( icalrecurrencetype_day_position( day ) );
     wdlst.append( pos );
   }
@@ -2400,18 +2419,21 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar )
     if ( !version ) {
       kDebug() << "No VERSION property found";
       d->mParent->setException( new ErrorFormat(
-                                  ErrorFormat::CalVersionUnknown ) );
+                                  ErrorFormat::CalVersionUnknown,
+                                  i18n( "No VERSION property found" ) ) );
       return false;
     }
     if ( strcmp( version, "1.0" ) == 0 ) {
       kDebug() << "Expected iCalendar, got vCalendar";
-      d->mParent->setException(
-        new ErrorFormat( ErrorFormat::CalVersion1,
-                         i18n( "Expected iCalendar format" ) ) );
+      d->mParent->setException( new ErrorFormat(
+                                  ErrorFormat::CalVersion1,
+                                  i18n( "Expected iCalendar, got vCalendar format" ) ) );
       return false;
     } else if ( strcmp( version, "2.0" ) != 0 ) {
       kDebug() << "Expected iCalendar, got unknown format";
-      d->mParent->setException( new ErrorFormat( ErrorFormat::CalVersionUnknown ) );
+      d->mParent->setException( new ErrorFormat(
+                                  ErrorFormat::CalVersionUnknown,
+                                  i18n( "Expected iCalendar, got unknown format" ) ) );
       return false;
     }
   }
@@ -2432,6 +2454,8 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar )
   icalcomponent *c;
 
   // Iterate through all todos
+  cal->beginBatchAdding();
+
   c = icalcomponent_get_first_component( calendar, ICAL_VTODO_COMPONENT );
   while ( c ) {
     Todo *todo = readTodo( c, tzlist );
@@ -2475,6 +2499,8 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar )
     c = icalcomponent_get_next_component( calendar, ICAL_VJOURNAL_COMPONENT );
   }
 
+  cal->endBatchAdding();
+
   // Post-Process list of events with relations, put Event objects in relation
   Event::List::ConstIterator eIt;
   for ( eIt = d->mEventsRelate.constBegin(); eIt != d->mEventsRelate.constEnd(); ++eIt ) {
@@ -2509,7 +2535,7 @@ void ICalFormatImpl::dumpIcalRecurrence( icalrecurrencetype r )
 {
   int i;
 
-  kDebug() << " Freq:" << r.freq;
+  kDebug() << " Freq:" << int( r.freq );
   kDebug() << " Until:" << icaltime_as_ical_string( r.until );
   kDebug() << " Count:" << r.count;
   if ( r.by_day[0] != ICAL_RECURRENCE_ARRAY_MAX ) {
@@ -2560,6 +2586,12 @@ icalcomponent *ICalFormatImpl::createScheduleComponent( IncidenceBase *incidence
 {
   icalcomponent *message = createCalendarComponent();
 
+#if 0
+  //
+  // Old versions of Outlook 2003 cannot handle TZIDs. So rely on UTC times.
+  // Keep the code here in case we ever need it.
+  //
+
   // Create VTIMEZONE components for this incidence
   ICalTimeZones zones;
   if ( incidence ) {
@@ -2604,10 +2636,41 @@ icalcomponent *ICalFormatImpl::createScheduleComponent( IncidenceBase *incidence
       }
     }
   }
-
+#else
+  if ( incidence ) {
+    if ( incidence->type() == "Event" ) {
+      Event *ev = static_cast<Event *>( incidence );
+      if ( ev ) {
+        if ( ev->dtStart().isValid() ) {
+          ev->setDtStart( ev->dtStart().toUtc() );
+        }
+        if ( ev->hasEndDate() && ev->dtEnd().isValid() ) {
+          ev->setDtEnd( ev->dtEnd().toUtc() );
+        }
+      }
+    } else if ( incidence->type() == "Todo" ) {
+      Todo *t = static_cast<Todo *>( incidence );
+      if ( t ) {
+        if ( t->hasStartDate() && t->dtStart().isValid() ) {
+          t->setDtStart( t->dtStart().toUtc() );
+        }
+        if ( t->hasDueDate() && t->dtDue().isValid() ) {
+          t->setDtDue( t->dtDue().toUtc() );
+        }
+      }
+    } else if ( incidence->type() == "Journal" ) {
+      Journal *j = static_cast<Journal *>( incidence );
+      if ( j ) {
+        if ( j->dtStart().isValid() ) {
+          j->setDtStart( j->dtStart().toUtc() );
+        }
+      }
+    }
+  }
+#endif
   icalproperty_method icalmethod = ICAL_METHOD_NONE;
 
-  switch (method) {
+  switch ( method ) {
   case iTIPPublish:
     icalmethod = ICAL_METHOD_PUBLISH;
     break;
